@@ -1,3 +1,11 @@
+( cd opt/kde/lib/kde3 ; rm -rf libvimpart.so )
+( cd opt/kde/lib/kde3 ; ln -sf libvimpart.so.0.0.0 libvimpart.so )
+( cd opt/kde/lib/kde3 ; rm -rf libvimpart.so.0 )
+( cd opt/kde/lib/kde3 ; ln -sf libvimpart.so.0.0.0 libvimpart.so.0 )
+( cd opt/kde/lib ; rm -rf libxvim.so.0 )
+( cd opt/kde/lib ; ln -sf libxvim.so.0.0.0 libxvim.so.0 )
+( cd opt/kde/lib ; rm -rf libxvim.so )
+( cd opt/kde/lib ; ln -sf libxvim.so.0.0.0 libxvim.so )
 ( cd opt/kde/share/doc/HTML/en/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/konq-plugins/crashes ; rm -rf common )
@@ -20,6 +28,8 @@
 ( cd opt/kde/share/doc/HTML/en/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/konq-plugins/fsview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/konq-plugins/uachanger ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/konq-plugins/mediaplayer ; rm -rf common )
